@@ -7,8 +7,7 @@
 
 # @black_format
 
-"""A GithubberRunner component, which is used to trigger a workflow on Github which
-runs a schema."""
+"""The implementation for the GithubRunner."""
 
 from __future__ import annotations
 
@@ -20,6 +19,7 @@ from autotransform.event.debug import DebugEvent
 from autotransform.event.handler import EventHandler
 from autotransform.event.remoterun import RemoteRunEvent
 from autotransform.event.update import RemoteUpdateEvent
+from autotransform.filter.shard import ShardFilter
 from autotransform.repo.github import GithubRepo
 from autotransform.runner.base import Runner, RunnerName
 from autotransform.schema.schema import AutoTransformSchema
@@ -28,7 +28,7 @@ from autotransform.util.github import GithubUtils
 
 class GithubRunner(Runner):
     """A Runner component that is used to trigger Github workflows. See
-    data/workflows/autotransform_runner.yml.
+    examples/workflows/autotransform.run.yml.
 
     Attributes:
         run_workflow (str): The name of the workflow to use for running a Schema.
@@ -52,17 +52,21 @@ class GithubRunner(Runner):
         event_handler = EventHandler.get()
         repo = schema.repo
 
-        # May add support for cross-repo usage but enforce that the workflow being invoked exists
-        # in the target repo for now
         assert isinstance(
             repo, GithubRepo
         ), "GithubRunner can only run using schemas that have Github repos"
 
         # Dispatch a Workflow run
+        workflow_inputs = {"schema": schema.config.schema_name}
+        if schema.config.max_submissions:
+            workflow_inputs["max_submissions"] = str(schema.config.max_submissions)
+        shard_filter = [filt for filt in schema.filters if isinstance(filt, ShardFilter)]
+        if shard_filter:
+            workflow_inputs["filter"] = json.dumps(shard_filter[0].bundle())
         workflow_url = GithubUtils.get(repo.full_github_name).create_workflow_dispatch(
             self.run_workflow,
-            repo.base_branch_name,
-            {"schema": json.dumps(schema.bundle())},
+            repo.base_branch,
+            workflow_inputs,
         )
         assert workflow_url is not None, "Failed to dispatch workflow request"
         event_handler.handle(DebugEvent({"message": "Successfully dispatched workflow run"}))
@@ -102,7 +106,7 @@ class GithubRunner(Runner):
         # Dispatch a Workflow run
         workflow_url = GithubUtils.get(repo.full_github_name).create_workflow_dispatch(
             self.update_workflow,
-            repo.base_branch_name,
+            repo.base_branch,
             {"change": json.dumps(change.bundle())},
         )
         assert workflow_url is not None, "Failed to dispatch workflow request"
